/*
 * langlist.h
 * Copyright (C) Kevin DeKorte 2008 <kdekorte@gmail.com>
 * 
 * langlist.h is free software.
 * 
 * You may redistribute it and/or modify it under the terms of the
 * GNU General Public License, as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

gchar const *const langlist[] = { "Abkhazian,abk,ab",
    "Achinese,ace",
    "Acoli,ach",
    "Adangme,ada",
    "Afar,aar,aa",
    "Afrihili,afh",
    "Afrikaans,afr,af",
    "Afro-Asiatic(Other),afa",
    "Akan,aka,ak",
    "Akkadian,akk",
    "Albanian,alb,sq",
    "Aleut,ale",
    "Algonquianlanguages,alg",
    "Altaic(Other),tut",
    "Amharic,amh,am",
    "Apachelanguages,apa",
    "Arabic,ara,ar",
    "Aragonese,arg,an",
    "Aramaic,arc",
    "Arapaho,arp",
    "Araucanian,arn",
    "Arawak,arw",
    "Armenian,arm,hy",
    "Artificial(Other),art",
    "Assamese,asm,as",
    "Asturian;Bable,ast",
    "Athapascanlanguages,ath",
    "Australianlanguages,aus",
    "Austronesian(Other),map",
    "Avaric,ava,av",
    "Avestan,ave,ae",
    "Awadhi,awa",
    "Aymara,aym,ay",
    "Azerbaijani,aze,az",
    "Bable;Asturian,ast",
    "Balinese,ban",
    "Baltic(Other),bat",
    "Baluchi,bal",
    "Bambara,bam,bm",
    "Bamilekelanguages,bai",
    "Banda,bad",
    "Bantu(Other),bnt",
    "Basa,bas",
    "Bashkir,bak,ba",
    "Basque,baq,eu",
    "Batak(Indonesia),btk",
    "Beja,bej",
    "Belarusian,bel,be",
    "Bemba,bem",
    "Bengali,ben,bn",
    "Berber(Other),ber",
    "Bhojpuri,bho",
    "Bihari,bih,bh",
    "Bikol,bik",
    "Bini,bin",
    "Bislama,bis,bi",
    "BokmBosnian,bos,bs",
    "Braj,bra",
    "Breton,bre,br",
    "Buginese,bug",
    "Bulgarian,bul,bg",
    "Buriat,bua",
    "Burmese,bur,my",
    "Caddo,cad",
    "Carib,car",
    "Castilian,spa,es",
    "Catalan,cat,ca",
    "Caucasian(Other),cau",
    "Cebuano,ceb",
    "Celtic(Other),cel",
    "CentralAmericanIndian(Other),cai",
    "Chagatai,chg",
    "Chamiclanguages,cmc",
    "Chamorro,cha,ch",
    "Chechen,che,ce",
    "Cherokee,chr",
    "Chewa;Chichewa;Nyanja,nya,ny",
    "Cheyenne,chy",
    "Chibcha,chb",
    "Chinese,chi,zh",
    "Chinookjargon,chn",
    "Chipewyan,chp",
    "Choctaw,cho",
    "Chuang;Zhuang,zha,za",
    "ChurchSlavic;OldChurchSlavonic,chu,cu",
    "Chuukese,chk",
    "Chuvash,chv,cv",
    "Coptic,cop",
    "Cornish,cor,kw",
    "Corsican,cos,co",
    "Cree,cre,cr",
    "Creek,mus",
    "Creolesandpidgins(Other),crp",
    "Creolesandpidgins,,cpe",
    "Creolesandpidgins,,cpf",
    "Creolesandpidgins,,cpp",
    "Croatian;Hrvatske,scr,hr",
    "Cushitic(Other),cus",
    "Czech,cze,cs",
    "Dakota,dak",
    "Danish,dan,da",
    "Dargwa,dar",
    "Dayak,day",
    "Delaware,del",
    "Dinka,din",
    "Divehi,div,dv",
    "Dogri,doi",
    "Dogrib,dgr",
    "Dravidian(Other),dra",
    "Duala,dua",
    "Dutch;Flemish,dut,nl",
    "Dutch,Middle(ca.1050-1350),dum",
    "Dyula,dyu",
    "Dzongkha,dzo,dz",
    "Efik,efi",
    "Egyptian(Ancient),egy",
    "Ekajuk,eka",
    "Elamite,elx",
    "English,eng,en",
    "English,Middle(1100-1500),enm",
    "English,Old(ca.450-1100),ang",
    "Esperanto,epo,eo",
    "Estonian,est,et",
    "Ewe,ewe,ee",
    "Ewondo,ewo",
    "Fang,fan",
    "Fanti,fat",
    "Faroese,fao,fo",
    "Fijian,fij,fj",
    "Finnish,fin,fi",
    "Finno-Ugrian(Other),fiu",
    "Fon,fon",
    "French,fre,fr",
    "French,Middle(ca.1400-1600),frm",
    "French,Old(842-ca.1400),fro",
    "Frisian,fry,fy",
    "Friulian,fur",
    "Fulah,ful,ff",
    "Ga,gaa",
    "Gaelic;ScottishGaelic,gla,gd",
    "Gallegan,glg,gl",
    "Ganda,lug,lg",
    "Gayo,gay",
    "Gbaya,gba",
    "Geez,gez",
    "Georgian,geo,ka",
    "German,ger,de",
    "German,Low;Saxon,Low;LowGerman;LowSaxon,nds",
    "German,MiddleHigh(ca.1050-1500),gmh",
    "German,OldHigh(ca.750-1050),goh",
    "Germanic(Other),gem",
    "Gikuyu;Kikuyu,kik,ki",
    "Gilbertese,gil",
    "Gondi,gon",
    "Gorontalo,gor",
    "Gothic,got",
    "Grebo,grb",
    "Greek,Ancient(to1453),grc",
    "Greek,gre,el",
    "Greenlandic;Kalaallisut,kal,kl",
    "Guarani,grn,gn",
    "Gujarati,guj,gu",
    "GwichHaida,hai",
    "Hausa,hau,ha",
    "Hawaiian,haw",
    "Hebrew,heb,he,iw",
    "Herero,her,hz",
    "Hiligaynon,hil",
    "Himachali,him",
    "Hindi,hin,hi",
    "HiriMotu,hmo,ho",
    "Hittite,hit",
    "Hmong,hmn",
    "Hungarian,hun,hu",
    "Hupa,hup",
    "Iban,iba",
    "Icelandic,ice,is",
    "Ido,ido,io",
    "Igbo,ibo,ig",
    "Ijo,ijo",
    "Iloko,ilo",
    "InariSami,smn",
    "Indic(Other),inc",
    "Indo-European(Other),ine",
    "Indonesian,ind,id",
    "Ingush,inh",
    "Interlingua(International,ina,ia",
    "Interlingue,ile,ie",
    "Inuktitut,iku,iu",
    "Inupiaq,ipk,ik",
    "Iranian(Other),ira",
    "Irish,gle,ga",
    "Irish,Middle(900-1200),mga",
    "Irish,Old(to900),sga",
    "Iroquoianlanguages,iro",
    "Italian,ita,it",
    "Japanese,jpn,ja",
    "Javanese,jav,jv",
    "Judeo-Arabic,jrb",
    "Judeo-Persian,jpr",
    "Kabardian,kbd",
    "Kabyle,kab",
    "Kachin,kac",
    "Kalaallisut;Greenlandic,kal,Kl",
    "Kamba,kam",
    "Kannada,kan,kn",
    "Kanuri,kau,kr",
    "Kara-Kalpak,kaa",
    "Karen,kar",
    "Kashmiri,kas,ks",
    "Kawi,kaw",
    "Kazakh,kaz,kk",
    "Khasi,kha",
    "Khmer,khm,km",
    "Khoisan(Other),khi",
    "Khotanese,kho",
    "Kikuyu;Gikuyu,kik,ki",
    "Kimbundu,kmb",
    "Kinyarwanda,kin,rw",
    "Kirghiz,kir,ky",
    "Klingon;tlhlngan-Hol,tlh",
    "Komi,kom,kv",
    "Kongo,kon,kg",
    "Konkani,kok",
    "Korean,kor,ko",
    "Kosraean,kos",
    "Kpelle,kpe",
    "Kru,kro",
    "Kuanyama;Kwanyama,kua,kj",
    "Kumyk,kum",
    "Kurdish,kur,ku",
    "Kurukh,kru",
    "Kutenai,kut",
    "Kwanyama,Kuanyama,kua,kj",
    "Ladino,lad",
    "Lahnda,lah",
    "Lamba,lam",
    "Lao,lao,lo",
    "Latin,lat,la",
    "Latvian,lav,lv",
    "Letzeburgesch;Luxembourgish,ltz,lb",
    "Lezghian,lez",
    "Limburgan;Limburger;Limburgish,lim,li",
    "Lingala,lin,ln",
    "Lithuanian,lit,lt",
    "LowGerman;LowSaxon;German,Low;Saxon,Low,nds",
    "Lozi,loz",
    "Luba-Katanga,lub,lu",
    "Luba-Lulua,lua",
    "Luiseno,lui",
    "LuleSami,smj",
    "Lunda,lun",
    "Luo(KenyaandTanzania),luo",
    "Lushai,lus",
    "Luxembourgish;Letzeburgesch,ltz,lb",
    "Macedonian,mac,mk",
    "Madurese,mad",
    "Magahi,mag",
    "Maithili,mai",
    "Makasar,mak",
    "Malagasy,mlg,mg",
    "Malay,may,ms",
    "Malayalam,mal,ml",
    "Maltese,mlt,mt",
    "Manchu,mnc",
    "Mandar,mdr",
    "Mandingo,man",
    "Manipuri,mni",
    "Manobolanguages,mno",
    "Manx,glv,gv",
    "Maori,mao,mi",
    "Marathi,mar,mr",
    "Mari,chm",
    "Marshallese,mah,mh",
    "Marwari,mwr",
    "Masai,mas",
    "Mayanlanguages,myn",
    "Mende,men",
    "Micmac,mic",
    "Minangkabau,min",
    "Miscellaneoualanguages,mis",
    "Mohawk,moh",
    "Moldavian,mol,mo",
    "Mon-Khmer(Other),mkh",
    "Mongo,lol",
    "Mongolian,mon,mn",
    "Mossi,mos",
    "Multiplelanguages,mul",
    "Mundalanguages,mun",
    "Nahuatl,nah",
    "Nauru,nau,na",
    "Navaho,Navajo,nav,nv",
    "Ndebele,North,nde,nd",
    "Ndebele,South,nbl,nr",
    "Ndonga,ndo,ng",
    "Neapolitan,nap",
    "Nepali,nep,ne",
    "Newari,new",
    "Nias,nia",
    "Niger-Kordofanian(Other),nic",
    "Nilo-Saharan(Other),ssa",
    "Niuean,niu",
    "Norse,Old,non",
    "NorthAmericanIndian(Other),nai",
    "NorthernSami,sme,se",
    "NorthNdebele,nde,nd",
    "Norwegian,nor,no",
    "NorwegianBokmNorwegianNynorsk;Nynorsk,Norwegian,nno,nn",
    "Nubianlanguages,nub",
    "Nyamwezi,nym",
    "Nyanja;Chichewa;Chewa,nya,ny",
    "Nyankole,nyn",
    "Nynorsk,Norwegian;NorwegianNynorsk,nno,nn",
    "Nyoro,nyo",
    "Nzima,nzi",
    "Occitan(post1500,NULL},;ProvenOjibwa,oji,oj",
    "OldBulgarian;OldSlavonic;ChurchSlavonic;,chu,cu",
    "Oriya,ori,or",
    "Oromo,orm,om",
    "Osage,osa",
    "Ossetian;Ossetic,oss,os",
    "Otomianlanguages,oto",
    "Pahlavi,pal",
    "Palauan,pau",
    "Pali,pli,pi",
    "Pampanga,pam",
    "Pangasinan,pag",
    "Panjabi,pan,pa",
    "Papiamento,pap",
    "Papuan(Other),paa",
    "Persian,per,fa",
    "Persian,Old(ca.600-400B.C.),peo",
    "Philippine(Other),phi",
    "Phoenician,phn",
    "Pohnpeian,pon",
    "Polish,pol,pl",
    "Portuguese,por,pt",
    "Prakritlanguages,pra",
    "ProvenProven",
    "Pushto,pus,ps",
    "Quechua,que,qu",
    "Raeto-Romance,roh,rm",
    "Rajasthani,raj",
    "Rapanui,rap",
    "Rarotongan,rar",
    "Reservedforlocaluse,qaa-qtz",
    "Romance(Other),roa",
    "Romanian,rum,ro",
    "Romany,rom",
    "Rundi,run,rn",
    "Russian,rus,ru",
    "Salishanlanguages,sal",
    "SamaritanAramaic,sam",
    "Samilanguages(Other),smi",
    "Samoan,smo,sm",
    "Sandawe,sad",
    "Sango,sag,sg",
    "Sanskrit,san,sa",
    "Santali,sat",
    "Sardinian,srd,sc",
    "Sasak,sas",
    "Saxon,Low;German,Low;LowSaxon;LowGerman,nds",
    "Scots,sco",
    "ScottishGaelic;Gaelic,gla,gd",
    "Selkup,sel",
    "Semitic(Other),sem",
    "Serbian,scc,sr",
    "Serer,srr",
    "Shan,shn",
    "Shona,sna,sn",
    "SichuanYi,iii,ii",
    "Sidamo,sid",
    "Signlanguages,sgn",
    "Siksika,bla",
    "Sindhi,snd,sd",
    "Sinhalese,sin,si",
    "Sino-Tibetan(Other),sit",
    "Siouanlanguages,sio",
    "SkoltSami,sms",
    "Slave(Athapascan),den",
    "Slavic(Other),sla",
    "Slovak,slo,sk",
    "Slovenian,slv,sl",
    "Sogdian,sog",
    "Somali,som,so",
    "Songhai,son",
    "Soninke,snk",
    "Sorbianlanguages,wen",
    "Sotho,Northern,nso",
    "Sotho,Southern,sot,st",
    "SouthAmericanIndian(Other),sai",
    "SouthernSami,sma",
    "SouthNdebele,nbl,nr",
    "Spanish,spa,es",
    "Sukuma,suk",
    "Sumerian,sux",
    "Sundanese,sun,su",
    "Susu,sus",
    "Swahili,swa,sw",
    "Swati,ssw,ss",
    "Swedish,swe,sv",
    "Syriac,syr",
    "Tagalog,tgl,tl",
    "Tahitian,tah,ty",
    "Tai(Other),tai",
    "Tajik,tgk,tg",
    "Tamashek,tmh",
    "Tamil,tam,ta",
    "Tatar,tat,tt",
    "Telugu,tel,te",
    "Tereno,ter",
    "Tetum,tet",
    "Thai,tha,th",
    "Tibetan,tib,bo",
    "Tigre,tig",
    "Tigrinya,tir,ti",
    "Timne,tem",
    "Tiv,tiv",
    "Tlingit,tli",
    "TokPisin,tpi",
    "Tokelau,tkl",
    "Tonga(Nyasa),tog",
    "Tonga(TongaIslands),ton,to",
    "Tsimshian,tsi",
    "Tsonga,tso,ts",
    "Tswana,tsn,tn",
    "Tumbuka,tum",
    "Tupilanguages,tup",
    "Turkish,tur,tr",
    "Turkish,Ottoman(1500-1928),ota",
    "Turkmen,tuk,tk",
    "Tuvalu,tvl",
    "Tuvinian,tyv",
    "Twi,twi,tw",
    "Ugaritic,uga",
    "Uighur,uig,ug",
    "Ukrainian,ukr,uk",
    "Umbundu,umb",
    "Undetermined,und",
    "Urdu,urd,ur",
    "Uzbek,uzb,uz",
    "Vai,vai",
    "Venda,ven,ve",
    "Vietnamese,vie,vi",
    "VolapVotic,vot",
    "Wakashanlanguages,wak",
    "Walamo,wal",
    "Walloon,wln,wa",
    "Waray,war",
    "Washo,was",
    "Welsh,wel,cy",
    "Wolof,wol,wo",
    "Xhosa,xho,xh",
    "Yakut,sah",
    "Yao,yao",
    "Yapese,yap",
    "Yiddish,yid,yi",
    "Yoruba,yor,yo",
    "Yupiklanguages,ypk",
    "Zande,znd",
    "Zapotec,zap",
    "Zenaga,zen",
    "Zulu,zul,zu",
    "Zuni,zun",
    NULL
};

gchar const *const codepagelist[] = { "",
    "UNICODE",
    "UTF-8",
    "BIG5",
    "CP874",
    "CP936",
    "CP949",
    "CP1250",
    "CP1251",
    "CP1256",
    "ISO-8859-1",
    "ISO-8859-2",
    "ISO-8859-3",
    "ISO-8859-4",
    "ISO-8859-5",
    "ISO-8859-6",
    "ISO-8859-7",
    "ISO-8859-8",
    "ISO-8859-9",
    "ISO-8859-10",
    "ISO-8859-11",
    "ISO-8859-12",
    "ISO-8859-13",
    "ISO-8859-14",
    "ISO-8859-15",
    "KOI8-R",
    "KOI8-U/RU",
    "enca",
    NULL
};
